@@ -8,7 +8,7 @@ package String::Tagged;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Scalar::Util qw( blessed );
 
@@ -1081,8 +1081,8 @@ sub get_tag_extent
    foreach my $t ( @$tags ) {
       my ( $ts, $te, $tn, undef, $tf ) = @$t;
 
-      next if $pos < $ts;
-      last if $pos >= $te;
+      last if $ts >  $pos;
+      next if $te <= $pos;
 
       next unless $tn eq $name;
 
